@@ -20,7 +20,7 @@
 
 /* MONGOC_USER_SET_CFLAGS is set from config based on what compiler flags were
  * used to compile mongoc */
-#define MONGOC_USER_SET_CFLAGS "-march=armv8-a -O2 -pipe -fstack-protector --param=ssp-buffer-size=4"
+#define MONGOC_USER_SET_CFLAGS "-march=armv8-a -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4"
 
 #define MONGOC_USER_SET_LDFLAGS "-Wl,-O1,--sort-common,--as-needed,-z,relro"
 
@@ -213,6 +213,15 @@
 #if MONGOC_HAVE_SOCKLEN != 1
 #  undef MONGOC_HAVE_SOCKLEN
 #endif
+
+
+/*
+ * Set from configure, see
+ * https://curl.haxx.se/mail/lib-2009-04/0287.html
+ */
+#define MONGOC_SOCKET_ARG2 struct sockaddr
+#define MONGOC_SOCKET_ARG3 socklen_t
+
 /*
  * NOTICE:
  * If you're about to update this file and add a config flag, make sure to
